===========
resplendent
===========

.. image:: https://dev.azure.com/AnthonyShaw/pytest-azurepipelines/_apis/build/status/tonybaloney.pytest-azurepipelines?branchName=master
   :target: https://dev.azure.com/AnthonyShaw/pytest-azurepipelines/_build/latest?definitionId=3?branchName=master
   :alt: Build status

.. image:: https://dev.azure.com/timgates/timgates/_apis/build/status/resplendent-dev.resplendent?branchName=master
   :target: https://dev.azure.com/timgates/timgates/_build/latest?definitionId=15&branchName=master
   :alt: Azure Status

.. image:: https://travis-ci.org/resplendent-dev/resplendent.svg?branch=master
   :target: https://travis-ci.org/resplendent-dev/resplendent
   :alt: Travis Status

.. image:: https://ci.appveyor.com/api/projects/status/u65kid1ueogx2o13/branch/master?svg=true
   :target: https://ci.appveyor.com/project/timgates42/resplendent
   :alt: Appveyor Status

.. image:: https://img.shields.io/pypi/v/resplendent.svg
   :target: https://pypi.org/project/resplendent
   :alt: PyPI version

.. image:: https://img.shields.io/pypi/pyversions/resplendent.svg
   :target: https://pypi.org/project/resplendent
   :alt: Python Versions

.. image:: https://img.shields.io/pypi/dm/resplendent.svg
   :target: https://pypi.org/project/resplendent
   :alt: PyPI downloads per month

.. image:: https://readthedocs.org/projects/resplendent/badge/?version=latest
   :target: https://resplendent.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/resplendent-dev/resplendent/badge.svg
   :target: https://coveralls.io/github/resplendent-dev/resplendent/
   :alt: Coverage Status

.. image:: https://camo.githubusercontent.com/28a51fe3a2c05048d8ca8ecd039d6b1619037326/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667
   :target: https://github.com/psf/black
   :alt: Black

A reStructuredText plugin filter for pyspelling.

More details can be found in the
`Online Documentation`_.

============
Installation
============

You can install resplendent for
`Python`_ via `pip`_ from `PyPI`_.

.. code-block:: bash

    pip install resplendent

Note: if using Python 3.4 the latest version of lxml only supports python 3.5 and above so install lxml 4.3.4


=============
Prerequisites
=============

- docutils
- pyspelling


======================
Download from PyPI.org
======================

https://pypi.org/project/resplendent/



============
Contributing
============

Contributions are very welcome, consider using the
`file an issue`_
to discuss the work before beginning, but if you already have a Pull Request
ready then this is no problem, please submit it and it will be very gratefully
considered. The `Contribution Guidelines`_
outlines the resplendent commitment to ensuring all
contributions receive appropriate recognition.

=======
License
=======


Distributed under the terms of the `GPLv3`_
license, "resplendent" is free and open source software


======
Issues
======

If you encounter any problems, please
`file an issue`_
along with a detailed description.

========================
Additional Documentation
========================

- `Online Documentation`_
- `News`_
- `Template Updates`_
- `Code of Conduct`_
- `Contribution Guidelines`_

.. _`Online Documentation`: https://resplendent.readthedocs.io/en/latest/
.. _`News`: NEWS.rst
.. _`Template Updates`: COOKIECUTTER_UPDATES.md
.. _`Code of Conduct`: CODE_OF_CONDUCT.md
.. _`Contribution Guidelines`: CONTRIBUTING.md
.. _`Python`: https://www.python.org/
.. _`pip`: https://pypi.org/project/pip/
.. _`PyPI`: https://pypi.org/
.. _`file an issue`: https://github.com/resplendent-dev/resplendent/issues
.. _`GPLv3`: https://opensource.org/licenses/GPL-3.0


